Получение статистики
Пред. | Глава 5. Использование | След.

## Получение статистики

С помощью команды ardj export-total-listeners можно получить информацию о том, какая композиция сколькими слушателями была прослушана за всё время работы станции. При каждом проигрывании композиции в базу данных складывается запись о времени проигрывания и количестве слушателей, которое сообщает icecast2; в этом отчёте данные суммируются. Результат выводится в формате CSV и пригоден для загрузки в любой табличный процессор. Формат файла и пример записи:

Пример 5.1. Общий отчёт о прослушиваниях

    last_played,artist,title,listeners,track_id,weight
    2011-10-24 07:48:15,20lb Sounds,Jimmy Carter,158,5327,1.18
    2011-10-24 17:54:55,2nd Season,It's Your Time To Rise,36,5735,1.25
    2011-10-24 01:01:02,30[eks],Hate It When They Do This,157,5736,1.25

Более подробную статистику за прошедшие сутки можно получить по команде ardj export-yesterday-listeners. В отчёте будут перечислены все проигранные композиции, без суммирования данных, наример:

Пример 5.2. Суточный отчёт о прослушиваниях

    time,track_id,artist,title,listeners
    2011-10-24 00:02:39,6384,StrangeZero,Zero Land,4
    2011-10-24 00:09:20,3714,Loveshadow,The Garden (Waiting),4
    2011-10-24 00:14:13,5076,Koalips,Wurtzite,4

Пред. | Наверх | След.
Оценка композиций | Начало | Глава 6. Web API